@@ -4,6 +4,7 @@ import (
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
 )
 
 const (
@@ -90,7 +91,7 @@ func (hg *Mercurial) shouldDisplay() bool {
 }
 
 func (hg *Mercurial) setDir(dir string) {
-	dir = runtime.ReplaceHomeDirPrefixWithTilde(hg.env, dir) // align with template PWD
+	dir = path.ReplaceHomeDirPrefixWithTilde(dir) // align with template PWD
 	if hg.env.GOOS() == runtime.WINDOWS {
 		hg.Dir = strings.TrimSuffix(dir, `\.hg`)
 		return
