@@ -6,9 +6,11 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/path"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
@@ -126,7 +128,7 @@ func (pt *Path) Enabled() bool {
 	pt.setStyle()
 	pwd := pt.env.Pwd()
 
-	pt.Location = pt.env.TemplateCache().AbsolutePWD
+	pt.Location = pt.env.Flags().AbsolutePWD
 	if pt.env.GOOS() == runtime.WINDOWS {
 		pt.Location = strings.ReplaceAll(pt.Location, `\`, `/`)
 	}
@@ -152,7 +154,7 @@ func (pt *Path) setPaths() {
 
 	pt.cygPath = displayCygpath()
 	pt.windowsPath = pt.env.GOOS() == runtime.WINDOWS && !pt.cygPath
-	pt.pathSeparator = pt.env.PathSeparator()
+	pt.pathSeparator = path.Separator()
 
 	pt.pwd = pt.env.Pwd()
 	if (pt.env.Shell() == shell.PWSH || pt.env.Shell() == shell.PWSH5) && len(pt.env.Flags().PSWD) != 0 {
@@ -186,10 +188,12 @@ func (pt *Path) Parent() string {
 	if !pt.endWithSeparator(pt.root) {
 		sb.WriteString(folderSeparator)
 	}
+
 	for _, folder := range folders[:len(folders)-1] {
 		sb.WriteString(folder)
 		sb.WriteString(folderSeparator)
 	}
+
 	return sb.String()
 }
 
@@ -246,13 +250,13 @@ func (pt *Path) getMaxWidth() int {
 
 	text, err := tmpl.Render()
 	if err != nil {
-		pt.env.Error(err)
+		log.Error(err)
 		return 0
 	}
 
 	value, err := strconv.Atoi(text)
 	if err != nil {
-		pt.env.Error(err)
+		log.Error(err)
 		return 0
 	}
 
@@ -267,6 +271,7 @@ func (pt *Path) getFolderSeparator() string {
 		if len(separator) == 0 {
 			return pt.pathSeparator
 		}
+
 		return separator
 	}
 
@@ -277,7 +282,7 @@ func (pt *Path) getFolderSeparator() string {
 
 	text, err := tmpl.Render()
 	if err != nil {
-		pt.env.Error(err)
+		log.Error(err)
 	}
 
 	if len(text) == 0 {
@@ -568,21 +573,21 @@ func (pt *Path) setMappedLocations() {
 			Context:  pt,
 		}
 
-		path, err := tmpl.Render()
+		location, err := tmpl.Render()
 		if err != nil {
-			pt.env.Error(err)
+			log.Error(err)
 		}
 
-		if len(path) == 0 {
+		if len(location) == 0 {
 			continue
 		}
 
 		// When two templates resolve to the same key, the values are compared in ascending order and the latter is taken.
-		if v, exist := mappedLocations[pt.normalize(path)]; exist && value <= v {
+		if v, exist := mappedLocations[pt.normalize(location)]; exist && value <= v {
 			continue
 		}
 
-		mappedLocations[pt.normalize(path)] = value
+		mappedLocations[pt.normalize(location)] = value
 	}
 
 	pt.mappedLocations = mappedLocations
@@ -660,9 +665,9 @@ func (pt *Path) parsePath(inputPath string) (string, string) {
 	}
 
 	if pt.cygPath {
-		path, err := pt.env.RunCommand("cygpath", "-u", inputPath)
-		if len(path) != 0 {
-			inputPath = path
+		cygPath, err := pt.env.RunCommand("cygpath", "-u", inputPath)
+		if len(cygPath) != 0 {
+			inputPath = cygPath
 			pt.pathSeparator = "/"
 		}
 
@@ -697,25 +702,26 @@ func (pt *Path) parsePath(inputPath string) (string, string) {
 	return root, relative
 }
 
-func (pt *Path) isRootFS(path string) bool {
-	return len(path) == 1 && runtime.IsPathSeparator(pt.env, path[0])
+func (pt *Path) isRootFS(inputPath string) bool {
+	return len(inputPath) == 1 && path.IsSeparator(inputPath[0])
 }
 
-func (pt *Path) endWithSeparator(path string) bool {
-	if len(path) == 0 {
+func (pt *Path) endWithSeparator(inputPath string) bool {
+	if len(inputPath) == 0 {
 		return false
 	}
-	return runtime.IsPathSeparator(pt.env, path[len(path)-1])
+
+	return path.IsSeparator(inputPath[len(inputPath)-1])
 }
 
 func (pt *Path) normalize(inputPath string) string {
 	normalized := inputPath
 
-	if strings.HasPrefix(normalized, "~") && (len(normalized) == 1 || runtime.IsPathSeparator(pt.env, normalized[1])) {
+	if strings.HasPrefix(normalized, "~") && (len(normalized) == 1 || path.IsSeparator(normalized[1])) {
 		normalized = pt.env.Home() + normalized[1:]
 	}
 
-	normalized = runtime.CleanPath(pt.env, normalized)
+	normalized = path.Clean(normalized)
 
 	if pt.env.GOOS() == runtime.WINDOWS || pt.env.GOOS() == runtime.DARWIN {
 		normalized = strings.ToLower(normalized)
@@ -827,9 +833,9 @@ func (pt *Path) makeFolderFormatMap() map[string]string {
 	if gitDirFormat := pt.props.GetString(GitDirFormat, ""); len(gitDirFormat) != 0 {
 		dir, err := pt.env.HasParentFilePath(".git", false)
 		if err == nil && dir.IsDir {
-			// Make it consistent with the modified path.
-			path := pt.join(pt.replaceMappedLocations(dir.ParentFolder))
-			folderFormatMap[path] = gitDirFormat
+			// Make it consistent with the modified parent.
+			parent := pt.join(pt.replaceMappedLocations(dir.ParentFolder))
+			folderFormatMap[parent] = gitDirFormat
 		}
 	}
 
