@@ -39,11 +39,10 @@ const (
 )
 
 type Svn struct {
-	scm
-
 	Working *SvnStatus
-	BaseRev int
 	Branch  string
+	scm
+	BaseRev int
 }
 
 func (s *Svn) Template() string {
@@ -60,6 +59,15 @@ func (s *Svn) Enabled() bool {
 	return true
 }
 
+func (s *Svn) CacheKey() (string, bool) {
+	dir, err := s.env.HasParentFilePath(".svn", true)
+	if err != nil {
+		return "", false
+	}
+
+	return dir.Path, true
+}
+
 func (s *Svn) shouldDisplay() bool {
 	if !s.hasCommand(SVNCOMMAND) {
 		return false
@@ -70,10 +78,6 @@ func (s *Svn) shouldDisplay() bool {
 		return false
 	}
 
-	if s.shouldIgnoreRootRepository(Svndir.ParentFolder) {
-		return false
-	}
-
 	if Svndir.IsDir {
 		s.workingDir = Svndir.Path
 		s.rootDir = Svndir.Path
