@@ -358,6 +358,10 @@ func Write(background, foreground color.Ansi, text string) {
 	currentColor.Pop()
 }
 
+func Len() int {
+	return length
+}
+
 func String() (string, int) {
 	defer func() {
 		length = 0
@@ -382,10 +386,6 @@ func writeEscapedAnsiString(text string) {
 	builder.WriteString(text)
 }
 
-func getAnsiFromColorString(colorString color.Ansi, isBackground bool) color.Ansi {
-	return Colors.ToAnsi(colorString, isBackground)
-}
-
 func write(s rune) {
 	if isInvisible {
 		return
@@ -428,17 +428,19 @@ func writeSegmentColors() {
 		return
 	}
 
-	if fg.IsTransparent() && len(BackgroundColor) != 0 { //nolint: gocritic
-		background := getAnsiFromColorString(BackgroundColor, false)
+	switch {
+	case fg.IsTransparent() && len(BackgroundColor) != 0:
+		background := Colors.ToAnsi(BackgroundColor, false)
 		writeEscapedAnsiString(fmt.Sprintf(colorise, background))
 		writeEscapedAnsiString(fmt.Sprintf(colorise, bg.ToForeground()))
-	} else if fg.IsTransparent() && !bg.IsEmpty() {
+	case fg.IsTransparent() && !bg.IsEmpty():
 		isTransparent = true
 		writeEscapedAnsiString(fmt.Sprintf(transparentStart, bg))
-	} else {
+	default:
 		if !bg.IsEmpty() && !bg.IsTransparent() {
 			writeEscapedAnsiString(fmt.Sprintf(colorise, bg))
 		}
+
 		if !fg.IsEmpty() {
 			writeEscapedAnsiString(fmt.Sprintf(colorise, fg))
 		}
@@ -494,7 +496,7 @@ func writeArchorOverride(match map[string]string, background color.Ansi, i int)
 	currentColor.Add(bg, fg)
 
 	if currentColor.Foreground().IsTransparent() && len(BackgroundColor) != 0 {
-		background := getAnsiFromColorString(BackgroundColor, false)
+		background := Colors.ToAnsi(BackgroundColor, false)
 		writeEscapedAnsiString(fmt.Sprintf(colorise, background))
 		writeEscapedAnsiString(fmt.Sprintf(colorise, currentColor.Background().ToForeground()))
 		return position
@@ -604,12 +606,20 @@ func asAnsiColors(background, foreground color.Ansi) (color.Ansi, color.Ansi) {
 	background = background.Resolve(CurrentColors, ParentColors)
 	foreground = foreground.Resolve(CurrentColors, ParentColors)
 
+	if bg, err := Colors.Resolve(background); err == nil {
+		background = bg
+	}
+
+	if fg, err := Colors.Resolve(foreground); err == nil {
+		foreground = fg
+	}
+
 	inverted := foreground == color.Transparent && len(background) != 0
 
-	backgroundAnsi := getAnsiFromColorString(background, !inverted)
-	foregroundAnsi := getAnsiFromColorString(foreground, false)
+	background = Colors.ToAnsi(background, !inverted)
+	foreground = Colors.ToAnsi(foreground, false)
 
-	return backgroundAnsi, foregroundAnsi
+	return background, foreground
 }
 
 func trimAnsi(text string) string {
