@@ -82,7 +82,9 @@ module.exports = {
             "segments/cli/pnpm",
             "segments/cli/quasar",
             "segments/cli/react",
+            "segments/cli/svelte",
             "segments/cli/talosctl",
+            "segments/cli/tauri",
             "segments/cli/terraform",
             "segments/cli/ui5tooling",
             "segments/cli/umbraco",
@@ -127,6 +129,7 @@ module.exports = {
             "segments/languages/dart",
             "segments/languages/dotnet",
             "segments/languages/elixir",
+            "segments/languages/fortran",
             "segments/languages/golang",
             "segments/languages/haskell",
             "segments/languages/java",
